pub struct MTBRegister<'a> {
pub addr: u32,
pub mask: u32,
pub descr: &'a str,
pub rmw: bool,
pub ro: bool,
pub pulse: bool,
}Expand description
A single 32bit register on the MTB with an associated mask to mask parts of ig
Fields
addr: u32the address of the register on the MTB (not Addr8)
mask: u32Some registers on the MTB share functionality, which we are splitting in different MTBRegisters. So even if two MTBRegisters share the same address, they might have a different mask to achieve different things and will thus have a different name.
descr: &'a strDescription about what is achieved when setting this register?
rmw: boolIs this register shared with other values? In that case we need to do a rmw operation instead of writing
ro: boolThis register is only read-only (e.g. providing a monitoring value
pulse: boolThis register is “pulse” type. So it can be asserted, but there is no point in reading it out, since it will reset itself.
Implementations